==> qtjambi-qt3dcore-debuginfo-macos-5.15.18.jar: sources/QtJambi3DCore/metainfo.cpp <==
#include <QtJambi/MetaInfo>

void initialize_meta_info_Qt3DCore();
void initialize_meta_info_Qt3DCore_QAbstractAspect();
void initialize_meta_info_Qt3DCore_QAbstractSkeleton();
void initialize_meta_info_Qt3DCore_QArmature();
void initialize_meta_info_Qt3DCore_QAspectEngine();
void initialize_meta_info_Qt3DCore_QAspectJob();
void initialize_meta_info_Qt3DCore_QBackendNode();
void initialize_meta_info_Qt3DCore_QBackendNodeMapper();
void initialize_meta_info_Qt3DCore_QComponent();
void initialize_meta_info_Qt3DCore_QComponentAddedChange();
void initialize_meta_info_Qt3DCore_QComponentRemovedChange();
void initialize_meta_info_Qt3DCore_QDynamicPropertyUpdatedChange();
void initialize_meta_info_Qt3DCore_QEntity();
void initialize_meta_info_Qt3DCore_QJoint();
void initialize_meta_info_Qt3DCore_QNode();
void initialize_meta_info_Qt3DCore_QNodeCommand();
void initialize_meta_info_Qt3DCore_QNodeCreatedChangeBase();
void initialize_meta_info_Qt3DCore_QNodeDestroyedChange();
void initialize_meta_info_Qt3DCore_QNodeId();
void initialize_meta_info_Qt3DCore_QNodeIdTypePair();
void initialize_meta_info_Qt3DCore_QPropertyNodeAddedChange();
void initialize_meta_info_Qt3DCore_QPropertyNodeRemovedChange();
void initialize_meta_info_Qt3DCore_QPropertyUpdatedChange();
void initialize_meta_info_Qt3DCore_QPropertyUpdatedChangeBase();
void initialize_meta_info_Qt3DCore_QPropertyValueAddedChange();
void initialize_meta_info_Qt3DCore_QPropertyValueAddedChangeBase();
void initialize_meta_info_Qt3DCore_QPropertyValueRemovedChange();
void initialize_meta_info_Qt3DCore_QPropertyValueRemovedChangeBase();
void initialize_meta_info_Qt3DCore_QSceneChange();
void initialize_meta_info_Qt3DCore_QSkeleton();
void initialize_meta_info_Qt3DCore_QSkeletonLoader();
void initialize_meta_info_Qt3DCore_QStaticPropertyUpdatedChangeBase();
void initialize_meta_info_Qt3DCore_QStaticPropertyValueAddedChangeBase();
void initialize_meta_info_Qt3DCore_QStaticPropertyValueRemovedChangeBase();
void initialize_meta_info_Qt3DCore_QTransform();

extern "C" Q_DECL_EXPORT jint JNICALL JNI_ONLOAD(JavaVM *, void *)
{
    QTJAMBI_LIBRARY_INITIALIZATION_METHOD_CALL("io.qt.qt3d.core")
    initialize_meta_info_Qt3DCore();
    initialize_meta_info_Qt3DCore_QAbstractAspect();
    initialize_meta_info_Qt3DCore_QAbstractSkeleton();
    initialize_meta_info_Qt3DCore_QArmature();
    initialize_meta_info_Qt3DCore_QAspectEngine();
    initialize_meta_info_Qt3DCore_QAspectJob();
    initialize_meta_info_Qt3DCore_QBackendNode();
    initialize_meta_info_Qt3DCore_QBackendNodeMapper();
    initialize_meta_info_Qt3DCore_QComponent();
    initialize_meta_info_Qt3DCore_QComponentAddedChange();
    initialize_meta_info_Qt3DCore_QComponentRemovedChange();
    initialize_meta_info_Qt3DCore_QDynamicPropertyUpdatedChange();
    initialize_meta_info_Qt3DCore_QEntity();
    initialize_meta_info_Qt3DCore_QJoint();
    initialize_meta_info_Qt3DCore_QNode();
    initialize_meta_info_Qt3DCore_QNodeCommand();
    initialize_meta_info_Qt3DCore_QNodeCreatedChangeBase();
    initialize_meta_info_Qt3DCore_QNodeDestroyedChange();
    initialize_meta_info_Qt3DCore_QNodeId();
    initialize_meta_info_Qt3DCore_QNodeIdTypePair();
    initialize_meta_info_Qt3DCore_QPropertyNodeAddedChange();
    initialize_meta_info_Qt3DCore_QPropertyNodeRemovedChange();
    initialize_meta_info_Qt3DCore_QPropertyUpdatedChange();
    initialize_meta_info_Qt3DCore_QPropertyUpdatedChangeBase();
    initialize_meta_info_Qt3DCore_QPropertyValueAddedChange();
    initialize_meta_info_Qt3DCore_QPropertyValueAddedChangeBase();
    initialize_meta_info_Qt3DCore_QPropertyValueRemovedChange();
    initialize_meta_info_Qt3DCore_QPropertyValueRemovedChangeBase();
    initialize_meta_info_Qt3DCore_QSceneChange();
    initialize_meta_info_Qt3DCore_QSkeleton();
    initialize_meta_info_Qt3DCore_QSkeletonLoader();
    initialize_meta_info_Qt3DCore_QStaticPropertyUpdatedChangeBase();
    initialize_meta_info_Qt3DCore_QStaticPropertyValueAddedChangeBase();
    initialize_meta_info_Qt3DCore_QStaticPropertyValueRemovedChangeBase();
    initialize_meta_info_Qt3DCore_QTransform();
    return QTJAMBI_ONLOAD_RETURN;
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QtJambi_1LibraryUtilities_internalAccess)(JNIEnv *env, jclass cls){
    jobject result{0};
    QTJAMBI_TRY{
        result = MetaInfoAPI::internalAccess(env, cls);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(env);
    }QTJAMBI_TRY_END
    return result;
}

==> qtjambi-qt3dcore-debuginfo-macos-6.6.3.jar: sources/QtJambi3DCore/metainfo.cpp <==
#include <QtJambi/MetaInfo>

void initialize_meta_info_Qt3DCore();
void initialize_meta_info_Qt3DCore_QAbstractAspect();
void initialize_meta_info_Qt3DCore_QAbstractFunctor();
void initialize_meta_info_Qt3DCore_QAbstractSkeleton();
void initialize_meta_info_Qt3DCore_QArmature();
void initialize_meta_info_Qt3DCore_QAspectEngine();
void initialize_meta_info_Qt3DCore_QAspectJob();
void initialize_meta_info_Qt3DCore_QAttribute();
void initialize_meta_info_Qt3DCore_QBackendNode();
void initialize_meta_info_Qt3DCore_QBackendNodeMapper();
void initialize_meta_info_Qt3DCore_QBoundingVolume();
void initialize_meta_info_Qt3DCore_QBuffer();
void initialize_meta_info_Qt3DCore_QComponent();
void initialize_meta_info_Qt3DCore_QCoreAspect();
void initialize_meta_info_Qt3DCore_QCoreSettings();
void initialize_meta_info_Qt3DCore_QEntity();
void initialize_meta_info_Qt3DCore_QGeometry();
void initialize_meta_info_Qt3DCore_QGeometryView();
void initialize_meta_info_Qt3DCore_QJoint();
void initialize_meta_info_Qt3DCore_QNode();
void initialize_meta_info_Qt3DCore_QNodeId();
void initialize_meta_info_Qt3DCore_QNodeIdTypePair();
void initialize_meta_info_Qt3DCore_QSkeleton();
void initialize_meta_info_Qt3DCore_QSkeletonLoader();
void initialize_meta_info_Qt3DCore_QTransform();

extern "C" Q_DECL_EXPORT jint JNICALL JNI_ONLOAD(JavaVM *, void *)
{
    QTJAMBI_LIBRARY_INITIALIZATION_METHOD_CALL("io.qt.qt3d.core")
    initialize_meta_info_Qt3DCore();
    initialize_meta_info_Qt3DCore_QAbstractAspect();
    initialize_meta_info_Qt3DCore_QAbstractFunctor();
    initialize_meta_info_Qt3DCore_QAbstractSkeleton();
    initialize_meta_info_Qt3DCore_QArmature();
    initialize_meta_info_Qt3DCore_QAspectEngine();
    initialize_meta_info_Qt3DCore_QAspectJob();
    initialize_meta_info_Qt3DCore_QAttribute();
    initialize_meta_info_Qt3DCore_QBackendNode();
    initialize_meta_info_Qt3DCore_QBackendNodeMapper();
    initialize_meta_info_Qt3DCore_QBoundingVolume();
    initialize_meta_info_Qt3DCore_QBuffer();
    initialize_meta_info_Qt3DCore_QComponent();
    initialize_meta_info_Qt3DCore_QCoreAspect();
    initialize_meta_info_Qt3DCore_QCoreSettings();
    initialize_meta_info_Qt3DCore_QEntity();
    initialize_meta_info_Qt3DCore_QGeometry();
    initialize_meta_info_Qt3DCore_QGeometryView();
    initialize_meta_info_Qt3DCore_QJoint();
    initialize_meta_info_Qt3DCore_QNode();
    initialize_meta_info_Qt3DCore_QNodeId();
    initialize_meta_info_Qt3DCore_QNodeIdTypePair();
    initialize_meta_info_Qt3DCore_QSkeleton();
    initialize_meta_info_Qt3DCore_QSkeletonLoader();
    initialize_meta_info_Qt3DCore_QTransform();
    return QTJAMBI_ONLOAD_RETURN;
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QtJambi_1LibraryUtilities_internalAccess)(JNIEnv *env, jclass cls){
    jobject result{0};
    QTJAMBI_TRY{
        result = MetaInfoAPI::internalAccess(env, cls);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(env);
    }QTJAMBI_TRY_END
    return result;
}
